@@ -1,5 +1,5 @@
 package PHP::Functions::Password;
-# $Id: Password.pm,v 1.3 2017/06/21 19:33:52 cmanley Exp $
+# $Id: Password.pm,v 1.4 2017/06/21 19:51:04 cmanley Exp $
 use strict;
 use warnings;
 use Carp qw(croak);
@@ -23,7 +23,7 @@ our %EXPORT_TAGS = (
 	'consts'	=> [ grep /^PASSWORD_/, @EXPORT_OK ],
 	'funcs'		=> [ grep /^password_/, @EXPORT_OK ],
 );
-our $VERSION = sprintf '%d.%02d', q{$Revision: 1.3 $} =~ m/ (\d+) \. (\d+) /xg;
+our $VERSION = sprintf '%d.%02d', q{$Revision: 1.4 $} =~ m/ (\d+) \. (\d+) /xg;
 
 use constant PASSWORD_BCRYPT => 1;
 use constant PASSWORD_DEFAULT => PASSWORD_BCRYPT;
@@ -134,7 +134,7 @@ sub password_get_info {
 =item password_hash($password, $algo, %options)
 
 Similar to L<http://php.net/manual/en/function.password-hash.php>
-with difference that the $algo argument is optional and defaults to PASSWORD_DEFAULT.
+with difference that the $algo argument is optional and defaults to PASSWORD_DEFAULT for your programming pleasure.
 
 =cut
 
